Capelayo Beach Restaurant | Eat & Drink in Mykonos | Mykonos, Cyclades, Greece
Author: ilove group ltd
Description: Selected local ingredients, creative Mediterranean cuisine, quality, superb location on Elia beach and unique atmosphere. Capelayo Restaurant is a must in the Mykonian food scene. The name Capelayo comes from the naval tradition of Mykonos and stands...
Keywords: Mykonos,Island,Greece,Resorts,Hotels,Villas,Bookings,Reviews,Holidays

- Restaurant Overview ×
- Restaurant Photos ×
- Restaurant Reviews ×
- View on Map ×

# Capelayo

###### Elia Beach, Elia, Mykonos, Cyclades, Greece, 84600

#### About Capelayo

Selected local ingredients, creative Mediterranean cuisine, quality, superb location on Elia beach and unique atmosphere. Capelayo Restaurant is a must in the Mykonian food scene. The name Capelayo comes from the naval tradition of Mykonos and stands for the sail of old small food carrier boats.
Capelayo Restaurant is divided in two levels. The upper level, decorated with atmospheric touches, travels your senses at another era as the tables seems to stand at the deck of an old ship. The ground level is dominated by the beach bar. Vivid music and refreshing cocktails by the beach.

#### Capelayo Features

Luxury Level: |
Popularity: |
Dress Code: | Casual, Beachwear
Entertainment: | DJ
Menu Style: | A la Carte
Cuisine: | Mediterranean
Meals Served: | Breakfast, Lunch
Ambiance: | Social

4 out of 5
100%
of visitors recommend it based on 1 reviews
Read Write a Review

- 00302289072001 - Line 1
- 00302289072002 - Line 1

- Email 1

- Website

Is this your business

#### Sleep Near By

- Myconian Imperial Hotel & Thalasso Spa 157 meters away
- Royal Myconian Resort & Thalasso Spa 236 meters away
- Greco Philia Luxury Suites & Villas 242 meters away
- Sunrise Hotel 754 meters away
- Agrari Beach Hotel 780 meters away

#### Eat & Drink Near By

- Elia Restaurant 82 meters away

#### Party Near By

- Cocktail Bar Agrari 715 meters away

#### See & Do Near By

- Elia Beach 116 meters away
- Elia Water Sports 138 meters away
- Water Action Sports 725 meters away
- Agrari Beach 753 meters away